Error Types for Spintronics Library
This module defines error types for the spintronics library to provide better error handling and reporting than panics.
Enums
- Error
- Main error type for the spintronics library
Functions
- dimension_
mismatch - Helper function to create dimension mismatch error
- invalid_
param - Helper function to create invalid parameter error
- not_
implemented - Helper function to create not implemented error
- numerical_
error - Helper function to create numerical error
Type Aliases
- Result
- Result type alias for spintronics operations